@@ -4,6 +4,7 @@ A collection of functions and objects for creating or placing inset axes.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import warnings
 from matplotlib import docstring
 import six
 from matplotlib.offsetbox import AnchoredOffsetbox
@@ -105,16 +106,16 @@ class AnchoredSizeLocator(AnchoredLocatorBase):
         dpi = renderer.points_to_pixels(72.)
 
         r, a = self.x_size.get_size(renderer)
-        width = w*r + a*dpi
+        width = w * r + a * dpi
 
         r, a = self.y_size.get_size(renderer)
-        height = h*r + a*dpi
+        height = h * r + a * dpi
         xd, yd = 0, 0
 
         fontsize = renderer.points_to_pixels(self.prop.get_size_in_points())
         pad = self.pad * fontsize
 
-        return width+2*pad, height+2*pad, xd+pad, yd+pad
+        return width + 2 * pad, height + 2 * pad, xd + pad, yd + pad
 
 
 class AnchoredZoomLocator(AnchoredLocatorBase):
@@ -122,7 +123,6 @@ class AnchoredZoomLocator(AnchoredLocatorBase):
                  borderpad=0.5,
                  bbox_to_anchor=None,
                  bbox_transform=None):
-
         self.parent_axes = parent_axes
         self.zoom = zoom
 
@@ -138,13 +138,10 @@ class AnchoredZoomLocator(AnchoredLocatorBase):
                              self.parent_axes.transData)
 
         x, y, w, h = bb.bounds
-
-        xd, yd = 0, 0
-
         fontsize = renderer.points_to_pixels(self.prop.get_size_in_points())
         pad = self.pad * fontsize
 
-        return w*self.zoom+2*pad, h*self.zoom+2*pad, xd+pad, yd+pad
+        return abs(w * self.zoom) + 2 * pad, abs(h * self.zoom) + 2 * pad, pad, pad
 
 
 class BboxPatch(Patch):
@@ -187,6 +184,7 @@ class BboxPatch(Patch):
                  Path.CLOSEPOLY]
 
         return Path(verts, codes)
+
     get_path.__doc__ = Patch.get_path.__doc__
 
 
@@ -321,6 +319,7 @@ class BboxConnector(Patch):
     def get_path(self):
         return self.connect_bbox(self.bbox1, self.bbox2,
                                  self.loc1, self.loc2)
+
     get_path.__doc__ = Patch.get_path.__doc__
 
 
@@ -376,6 +375,7 @@ class BboxConnectorPatch(BboxConnector):
                        list(path2.vertices) +
                        [path1.vertices[0]])
         return Path(path_merged)
+
     get_path.__doc__ = BboxConnector.get_path.__doc__
 
 
@@ -394,8 +394,16 @@ def inset_axes(parent_axes, width, height, loc=1,
     """
     Create an inset axes with a given width and height.
 
-    Both sizes used can be specified either in inches or percentage of the
-    parent axes.
+    Both sizes used can be specified either in inches or percentage.
+    For example,::
+
+        inset_axes(parent_axes, width='40%%', height='30%%', loc=3)
+
+    creates in inset axes in the lower left corner of *parent_axes* which spans
+    over 30%% in height and 40%% in width of the *parent_axes*. Since the usage
+    of `.inset_axes` may become slightly tricky when exceeding such standard
+    cases, it is recommended to read
+    :ref:`the examples <sphx_glr_gallery_axes_grid1_inset_locator_demo.py>`.
 
     Parameters
     ----------
@@ -403,7 +411,12 @@ def inset_axes(parent_axes, width, height, loc=1,
         Axes to place the inset axes.
 
     width, height : float or str
-        Size of the inset axes to create.
+        Size of the inset axes to create. If a float is provided, it is
+        the size in inches, e.g. *width=1.3*. If a string is provided, it is
+        the size in relative units, e.g. *width='40%%'*. By default, i.e. if
+        neither *bbox_to_anchor* nor *bbox_transform* are specified, those
+        are relative to the parent_axes. Otherwise they are to be understood
+        relative to the bounding box provided via *bbox_to_anchor*.
 
     loc : int or string, optional, default to 1
         Location to place the inset axes. The valid locations are::
@@ -420,14 +433,29 @@ def inset_axes(parent_axes, width, height, loc=1,
             'center'       : 10
 
     bbox_to_anchor : tuple or `matplotlib.transforms.BboxBase`, optional
-        Bbox that the inset axes will be anchored. Can be a tuple of
-        [left, bottom, width, height], or a tuple of [left, bottom].
+        Bbox that the inset axes will be anchored to. If None,
+        *parent_axes.bbox* is used. If a tuple, can be either
+        [left, bottom, width, height], or [left, bottom].
+        If the kwargs *width* and/or *height* are specified in relative units,
+        the 2-tuple [left, bottom] cannot be used. Note that
+        the units of the bounding box are determined through the transform
+        in use. When using *bbox_to_anchor* it almost always makes sense to
+        also specify a *bbox_transform*. This might often be the axes transform
+        *parent_axes.transAxes*.
 
     bbox_transform : `matplotlib.transforms.Transform`, optional
-        Transformation for the bbox. if None, `parent_axes.transAxes` is used.
+        Transformation for the bbox that contains the inset axes.
+        If None, a `.transforms.IdentityTransform` is used (i.e. pixel
+        coordinates). This is useful when not providing any argument to
+        *bbox_to_anchor*. When using *bbox_to_anchor* it almost always makes
+        sense to also specify a *bbox_transform*. This might often be the
+        axes transform *parent_axes.transAxes*. Inversely, when specifying
+        the axes- or figure-transform here, be aware that not specifying
+        *bbox_to_anchor* will use *parent_axes.bbox*, the units of which are
+        in display (pixel) coordinates.
 
     axes_class : `matplotlib.axes.Axes` type, optional
-        If specified, the inset axes created with be created with this class's
+        If specified, the inset axes created will be created with this class's
         constructor.
 
     axes_kwargs : dict, optional
@@ -437,6 +465,8 @@ def inset_axes(parent_axes, width, height, loc=1,
 
     borderpad : float, optional
         Padding between inset axes and the bbox_to_anchor. Defaults to 0.5.
+        The units are axes font size, i.e. for a default font size of 10 points
+        *borderpad = 0.5* is equivalent to a padding of 5 points.
 
     Returns
     -------
@@ -453,9 +483,24 @@ def inset_axes(parent_axes, width, height, loc=1,
         inset_axes = axes_class(parent_axes.figure, parent_axes.get_position(),
                                 **axes_kwargs)
 
+    if bbox_transform in [parent_axes.transAxes,
+                          parent_axes.figure.transFigure]:
+        if bbox_to_anchor is None:
+            warnings.warn("Using the axes or figure transform requires a "
+                          "bounding box in the respective coordinates. "
+                          "Using bbox_to_anchor=(0,0,1,1) now.")
+            bbox_to_anchor = (0, 0, 1, 1)
+
     if bbox_to_anchor is None:
         bbox_to_anchor = parent_axes.bbox
 
+    if isinstance(bbox_to_anchor, tuple) and \
+        (isinstance(width, str) or isinstance(height, str)):
+        if len(bbox_to_anchor) != 4:
+            raise ValueError("Using relative units for width or height "
+                             "requires to provide a 4-tuple or a "
+                             "`BBox` instance to `bbox_to_anchor.")
+
     axes_locator = AnchoredSizeLocator(bbox_to_anchor,
                                        width, height,
                                        loc=loc,
@@ -476,7 +521,8 @@ def zoomed_inset_axes(parent_axes, zoom, loc=1,
                       axes_kwargs=None,
                       borderpad=0.5):
     """
-    Create an anchored inset axes by scaling a parent axes.
+    Create an anchored inset axes by scaling a parent axes. For usage, also see
+    :ref:`the examples <sphx_glr_gallery_axes_grid1_inset_locator_demo2.py>`.
 
     Parameters
     ----------
@@ -503,14 +549,29 @@ def zoomed_inset_axes(parent_axes, zoom, loc=1,
             'center'       : 10
 
     bbox_to_anchor : tuple or `matplotlib.transforms.BboxBase`, optional
-        Bbox that the inset axes will be anchored. Can be a tuple of
-        [left, bottom, width, height], or a tuple of [left, bottom].
+        Bbox that the inset axes will be anchored to. If None,
+        *parent_axes.bbox* is used. If a tuple, can be either
+        [left, bottom, width, height], or [left, bottom].
+        If the kwargs *width* and/or *height* are specified in relative units,
+        the 2-tuple [left, bottom] cannot be used. Note that
+        the units of the bounding box are determined through the transform
+        in use. When using *bbox_to_anchor* it almost always makes sense to
+        also specify a *bbox_transform*. This might often be the axes transform
+        *parent_axes.transAxes*.
 
     bbox_transform : `matplotlib.transforms.Transform`, optional
-        Transformation for the bbox. if None, `parent_axes.transAxes` is used.
+        Transformation for the bbox that contains the inset axes.
+        If None, a `.transforms.IdentityTransform` is used (i.e. pixel
+        coordinates). This is useful when not providing any argument to
+        *bbox_to_anchor*. When using *bbox_to_anchor* it almost always makes
+        sense to also specify a *bbox_transform*. This might often be the
+        axes transform *parent_axes.transAxes*. Inversely, when specifying
+        the axes- or figure-transform here, be aware that not specifying
+        *bbox_to_anchor* will use *parent_axes.bbox*, the units of which are
+        in display (pixel) coordinates.
 
     axes_class : `matplotlib.axes.Axes` type, optional
-        If specified, the inset axes created with be created with this class's
+        If specified, the inset axes created will be created with this class's
         constructor.
 
     axes_kwargs : dict, optional
@@ -520,6 +581,8 @@ def zoomed_inset_axes(parent_axes, zoom, loc=1,
 
     borderpad : float, optional
         Padding between inset axes and the bbox_to_anchor. Defaults to 0.5.
+        The units are axes font size, i.e. for a default font size of 10 points
+        *borderpad = 0.5* is equivalent to a padding of 5 points.
 
     Returns
     -------
@@ -582,7 +645,8 @@ def mark_inset(parent_axes, inset_axes, loc1, loc2, **kwargs):
     """
     rect = TransformedBbox(inset_axes.viewLim, parent_axes.transData)
 
-    pp = BboxPatch(rect, fill=False, **kwargs)
+    fill = kwargs.pop("fill", False)
+    pp = BboxPatch(rect, fill=fill, **kwargs)
     parent_axes.add_patch(pp)
 
     p1 = BboxConnector(inset_axes.bbox, rect, loc1=loc1, **kwargs)
